Skip to contents

Dataset includes weekly laboratory confirmed DENV-3 cases from Central Division in Fiji, during an outbreak in 2013 and 2014 as well as monthly average temperature data for Fiji and yearly population size for Central Division during this period

Usage

fiji_2014

Format

An object of class data.frame with 44 rows and 4 columns.

Details

A data frame with 44 rows and 3 columns:

date

Date of epidemiological week

cases

Number of laboratory confirmed cases in Central Division, Fiji

av_temp

Average monthly temperature for Fiji, in °C

pop

Yearly population size for Central Division

...

#' @source https://github.com/adamkucharski/fiji-denv3-2014